"use client";

import React, { useEffect, useRef, useState } from "react";

import { ButtonProps } from "@/components/ui/button";
import { cn } from "@/lib/utils";

export interface ContentButton extends ButtonProps {
	text: string;
}

export interface ContentProps {
	title?: string;
	space?: string;
	underlineColor?: "white" | "custom-primary-accent" | "custom-secondary";
	padding?: "none" | "small" | "medium" | "large";
	titleSize?: string;
	titleColor?: string;
	textColor?: string;
	className?: string;
	centered?: boolean; // New prop for centering
}

export const ContentLines: React.FC<ContentProps> = ({
	title,
	titleSize = "text-lg",
	space,
	underlineColor = "white",
	padding = "medium",
	textColor = "text-white",
	className,
	centered = false, // Default to false for backwards compatibility
}) => {
	const titleRef = useRef<HTMLSpanElement>(null);
	const [underlineWidths, setUnderlineWidths] = useState<number[]>([0, 0, 0]);

	useEffect(() => {
		if (titleRef.current && title) {
			const width = titleRef.current.offsetWidth;
			setUnderlineWidths([
				Math.round(width * 0.2),
				Math.round(width * 0.3),
				Math.round(width * 0.5),
			]);
		}
	}, [title]);

	const paddingClasses = {
		none: "p-0",
		small: "p-4",
		medium: "p-6",
		large: "py-6 px-8",
	};

	return (
		<div
			className={cn(
				`flex flex-col ${paddingClasses[padding]} gap-${space}`,
				centered && "items-center", // Add centering when the centered prop is true
				className
			)}
		>
			{title && (
				<div
					className={cn("relative", centered && "flex flex-col items-center")}
				>
					<span ref={titleRef} className={`font-medium ${textColor} ${titleSize}`}>
						{title}
					</span>
					<div
						className={cn(
							"absolute -bottom-2 left-0 right-0 flex gap-1",
							centered && "justify-center"
						)}
					>
						{underlineWidths?.map((width, index) => (
							<div
								key={index}
								className={`h-1 rounded-md bg-${underlineColor}`}
								style={{ width: `${width}px` }}
							/>
						))}
					</div>
				</div>
			)}
		</div>
	);
};
